function [input, target] = genvinput(N,r,M,maxv,frames)
% 2D particle simulator that generates an input and target vectors to be used
% in a collision reaction learning algorithm
% N -> resolution
% r -> radius of each particle in pixels
% M -> number of particles
% maxv -> maximum velocity (displacement per frame) in each direction
% frames -> number of frames to simulate
rand('seed', 1);

p = genparticles(N,r,M,maxv);

% assign random velocity vectors:
v = 2.0*maxv*(rand(size(p)) - 0.5);

% prepare for frame loop
pn = p;
len = length(pn);
collisions = 0;

% allocate space for output vectors
input = zeros(6, frames);
target = zeros(6, frames);

for t = 1:frames
  pn = round(pn + v); % update positions according to current velocity

  % check if two particles intersect, if so change velocity
  for i = 1:(len-1)
    for j = (i+1):len
      if norm(pn(:,i) - pn(:,j)) < r+r-2 % ball-ball collision detected
        collisions = collisions + 1; % count number of collisions

        rel = pn(:,j) - pn(:,i); % relative posn of j (from i)
        input(:,collisions) = [rel; v(:,i); v(:,j)]; % phase before the collision

        % compute ball-ball collisions
        [pos vel bitn] = bbcollision(pn(:,i), pn(:,j), v(:,i), v(:,j),r);
        pn(:,i) = pos(:,1);
        pn(:,j) = pos(:,2);
        v(:,i) = vel(:,1);
        v(:,j) = vel(:,2);

        target(:,collisions) = [bitn; v(:,i); v(:,j)]; % phase after collision
      end % if ball-ball collision detected
    end % for each ball
  end % for each ball

  [pn v] = wbcollisions(pn, v, N, r); % compute all wall-ball collisions
end

% clean trailing zeros
input(:,collisions+1:end) = [];
target(:,collisions+1:end) = [];

collisions % display the number of collisions
