function [errp, errv] = simvnet(N,r,M,maxv,frames,seed,net)
% 2D particle simulator using a learned collision function
% N -> resolution
% r -> radius of each particle in pixels
% M -> number of particles
% maxv -> maximum velocity (displacement per frame) in each direction
% seed -> a random seed used to produce random colors and initial conditions
% net -> learned collision function

bbcol = @(p1, p2, v1, v2, r) bbcolnet(p1,p2,v1,v2,net);
[errp errv] = sp(N,r,M,maxv,frames,seed,bbcol);

end % simvnet

function [pos vel] = bbcolnet(p1, p2, v1, v2, net)
  % use the learned function for collision response
  res = net([p2 - p1; v1; v2]); 
  bitn = res(1:2);
  vel = reshape(res(3:6), 2, 2);
  pos(:,2) = round(p2 + bitn);
  pos(:,1) = round(p1 - bitn);
end % bbcolnet
