function [net, errp, errv] = svn(N,r,M,maxv,ftrain,fsim,numneurons)
% Program that trains a neural network the impulse reaction function in
% a 2D particle collision simulator, and then simulates fsim frames
% of colliding particles using this neural network generatively.
% in addition this program will create a plot of the error in velocity and
% position after the collision, and display error means
% INPUTS:
%          N -> resolution
%          r -> radius of each particle in pixels
%          M -> number of particles
%       maxv -> maximum velocity (displacement per frame) in each direction
%     ftrain -> number of frames to train the neural network with
%       fsim -> number of frames to simulate on output
% numneurons -> number of neurons in each layer to use on the network
% OUTPUTS:
%        net -> the trained nural network 
%       errp -> the error in position at each collision
%       errv -> the error in velocity at each collision

disp('Generating input...');
[x y] = genvinput(N,r,M,maxv,ftrain);
disp('Training neural network...');
net = prepnet(numneurons, x, y);
disp('Simulating...');
[errp, errv] = simvnet(N,r,M,maxv,fsim,3,net);
ploterr(errp, errv, numneurons, ftrain);
fprintf('velocity error mean = %f\n', mean(errv));
fprintf('position error mean = %f\n', mean(errp));
